@@ -535,13 +535,14 @@ class _TestRequestSpecObject(object):
 
         # object fields
         for field in ['image', 'numa_topology', 'pci_requests', 'flavor',
-                'retry', 'limits']:
+                      'limits']:
             self.assertEqual(
                     getattr(req_obj, field).obj_to_primitive(),
                     getattr(serialized_obj, field).obj_to_primitive())
 
         self.assertIsNone(serialized_obj.instance_group.members)
         self.assertIsNone(serialized_obj.instance_group.hosts)
+        self.assertIsNone(serialized_obj.retry)
 
     def test_create(self):
         req_obj = fake_request_spec.fake_spec_obj(remove_id=True)
